tonalitytools.ExtentIndicator
=============================

.. inheritance-diagram:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.name

.. autoattribute:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.number

.. autoattribute:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.__eq__

.. automethod:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.__ne__

.. automethod:: abjad.tools.tonalitytools.ExtentIndicator.ExtentIndicator.ExtentIndicator.__repr__
